@@ -269,11 +269,17 @@ class NoteheadEngraver(Engraver):
         self.m_xpos = dict[self.m_timepos].m_music
     def engrave(self, widget, gc, staff_yoffset):
         dim = dimentions[self.m_fontsize]
+        # Have to adjust holenotes a little to the left to be on the middle
+        # of the ledger line.
+        if self.m_head == 0:
+            xx = -2
+        else:
+            xx = 0
         widget.window.draw_pixbuf(gc, 
             gtk.gdk.pixbuf_new_from_file(fetadir+'/feta%i-noteheads-%i.xpm' \
                 % (self.m_fontsize, self.m_head)),
             0, 0,
-            self.m_xpos + self.m_shift * dim.xshift,
+            self.m_xpos + self.m_shift * dim.xshift + xx,
             int(staff_yoffset + dim.linespacing*self.m_ypos/2 - 4))
         for n in range(self.m_numdots):
             widget.window.draw_pixbuf(gc,
