@@ -17,6 +17,7 @@
 
 import sys, os, tempfile, signal
 import mfutils
+import textwrap
 
 def ms_win_kill(pid):
     import win32api
@@ -28,10 +29,9 @@ class MidiFileSynth:
     def __init__(self, cmd, verbose_init):
         self.m_type_major = "Midifile"
         self.m_cmd = cmd
-        self.m_tmpfilename = tempfile.mktemp()
-        self.grab_tmp_file(self.m_tmpfilename)
-        self.m_pidfile = tempfile.mktemp()
-        self.grab_tmp_file(self.m_pidfile)
+        self.m_tmpfilename = tempfile.mkstemp(".mid")[1]
+        self.error_report_cb = None
+        self.m_pidfile = tempfile.mkstemp()[1]
         if sys.platform == 'win32':
             self.play_track = self._play_track_system
         else:
@@ -41,16 +41,6 @@ class MidiFileSynth:
             print "cmdline:", self.m_cmd
             print "tmpfile:", self.m_tmpfilename
         self.__child_pid = None
-    def grab_tmp_file(self, fn):
-        try:
-            # create the file so nobody else takes it
-            fd = os.open(fn, os.O_CREAT|os.O_EXCL|os.O_TRUNC|os.O_RDWR, 0600)
-            os.close(fd)
-        except IOError, e:
-            print "trouble creating tmp file. This should *not* happen."
-            print "Please complaint to bug-solfege@gnu.org"
-            print "Exception:", e
-            raise "Shit"
     def close(self):
         if os.path.exists(self.m_tmpfilename):
             os.remove(self.m_tmpfilename)
@@ -69,8 +59,11 @@ class MidiFileSynth:
         track.prepend_bpm(60)
         self.create_midifile(track)
         if not os.path.isfile(self.m_cmd.split()[0]):
-            print >> sys.stderr, "The program '%s' does not exist." % self.m_cmd.split()[0]
-            print >> sys.stderr, "Please check the sound setup in the preferences window."
+            msg = _("""Failed to play music because the selected midi player program '%s' does not exist. You have to change the sound setup from the preferences window (Ctrl-F12).""") % self.m_cmd.split()[0]
+            if self.error_report_cb:
+                self.error_report_cb(msg)
+            else:
+                print >> sys.stderr, "\n".join(textwrap.wrap(msg))
             return
         if self.__child_pid:
             try:
