@@ -188,7 +188,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_select_questions.show()
 
     def update_select_question_buttons(self):
-        if self.get_bool('gui/expert_mode'):
+        if self.m_t.m_custom_mode:
             self.g_select_questions_category_box.show()
             self.g_select_questions.initialize(self.m_t.m_P.header.fillnum,
                                  self.m_t.m_P.header.filldir)
@@ -243,7 +243,10 @@ class Gui(abstract.LessonbasedGui):
     def update_gui_after_lessonfile_change(self):
         self.g_music_displayer.clear()
         self.update_select_question_buttons()
-        self.set_lesson_heading(self.m_t.m_P.header.lesson_heading)
+        if self.m_t.m_P.header.lesson_heading:
+            self.set_lesson_heading(self.m_t.m_P.header.lesson_heading)
+        else:
+            self.set_lesson_heading(_("Identify the chord"))
         self.g_new.set_sensitive(True)
         self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
         if not [q for q in self.m_t.m_P.m_questions if 'toptone' in q]:
@@ -461,6 +464,9 @@ class Gui(abstract.LessonbasedGui):
             self.g_win.display_question_music_error_message(
                 self.m_t.m_P._idx, self.get_string('lessonfile'), e)
     def on_start_practise(self):
+        self.m_t.m_custom_mode = self.get_bool('gui/expert_mode')
+        for question in self.m_t.m_P.m_questions:
+            question['active'] = 1
         self.update_gui_after_lessonfile_change()
         self.g_flashbar.require_size([
             _("Click 'New chord' to begin."),
