@@ -33,6 +33,7 @@ class Teacher(abstract.LessonbasedTeacher):
     def __init__(self, exname, app):
         abstract.LessonbasedTeacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.IdByNameLessonfile
+        self.m_custom_mode = False
     def give_up(self):
         self.q_status = const.QSTATUS_GIVE_UP
     def new_question(self):
@@ -47,17 +48,11 @@ class Teacher(abstract.LessonbasedTeacher):
                  and self.q_status in [const.QSTATUS_NEW, const.QSTATUS_WRONG]:
             return Teacher.ERR_PICKY
 
-        if self.get_string('first_interval_type') in ['harmonic', 'up', 'up/down']:
-            first = self.get_list('first_interval_up')
-        else:
-            first = []
-        if self.get_string('first_interval_type') in ['down', 'up/down']:
+        first = self.get_list('first_interval_up')
+        if self.get_string('first_interval_type') == 'melodic':
             first = first + map(lambda a: -a, self.get_list('first_interval_down'))
-        if self.get_string('last_interval_type') in ['harmonic', 'up', 'up/down']:
-            last = self.get_list('last_interval_up')
-        else:
-            last = []
-        if self.get_string('last_interval_type') in ['down', 'up/down']:
+        last = self.get_list('last_interval_up')
+        if self.get_string('last_interval_type') == 'melodic':
             last = last + map(lambda a: -a, self.get_list('last_interval_down'))
         if not (first and last):
             return self.ERR_CONFIGURE
@@ -164,14 +159,8 @@ class Gui(abstract.Gui):
             D['harmonic'] = b = gu.RadioButton(None, _("Harmonic"), callback)
             b.set_data('idir', 'harmonic')
             box.pack_start(b, False)
-            D['up'] = b = gu.RadioButton(b, _("Melodic up"), callback)
-            b.set_data('idir', 'up')
-            box.pack_start(b, False)
-            D['down'] = b = gu.RadioButton(b, _("Melodic down"), callback)
-            b.set_data('idir', 'down')
-            box.pack_start(b, False)
-            D['up/down'] = b = gu.RadioButton(b, _("Melodic up/down"), callback)
-            b.set_data('idir', 'up/down')
+            D['melodic'] = b = gu.RadioButton(b, _("Melodic"), callback)
+            b.set_data('idir', 'melodic')
             box.pack_start(b, False)
             return D
         #---------
@@ -199,12 +188,12 @@ class Gui(abstract.Gui):
         self.g_intervalconfig_box.pack_start(self.g_last_interval_down, False)
         #------------
         s = self.get_string('first_interval_type')
-        if not s in ('harmonic', 'up', 'down', 'up/down'):
+        if not s in ('harmonic', 'melodic'):
             self.set_string('first_interval_type', 'harmonic')
         self.g_rdbs[0][self.get_string('first_interval_type')].set_active(True)
         self.update_first(self.g_rdbs[0][self.get_string('first_interval_type')])
         s = self.get_string('last_interval_type')
-        if not s in ('harmonic', 'up', 'down', 'up/down'):
+        if not s in ('harmonic', 'melodic'):
             self.set_string('last_interval_type', 'harmonic')
         self.g_rdbs[1][self.get_string('last_interval_type')].set_active(True)
         self.update_last(self.g_rdbs[1][self.get_string('last_interval_type')])
@@ -214,33 +203,31 @@ class Gui(abstract.Gui):
     def _watch_1_cb(self, name):
         self._ignore_events = 1
         self.g_rdbs[0][self.get_string('first_interval_type')].set_active(1)
-        self.g_first_interval_up.set_sensitive(
-                  self.get_string('first_interval_type') \
-                    in ['harmonic', 'up', 'up/down'])
         self.g_first_interval_down.set_sensitive(
-                self.get_string('first_interval_type') in ['up/down', 'down'])
+                self.get_string('first_interval_type') == 'melodic')
         self._ignore_events = 0
     def _watch_2_cb(self, name):
         self._ignore_events = 1
         self.g_rdbs[1][self.get_string('last_interval_type')].set_active(1)
-        self.g_last_interval_up.set_sensitive(
-                 self.get_string('last_interval-type') \
-                   in ['harmonic', 'up', 'up/down'])
         self.g_last_interval_down.set_sensitive(
-                self.get_string('last_interval_type') in ['up/down', 'down'])
+                self.get_string('last_interval_type') == 'melodic')
         self._ignore_events = 0
     def update_first(self, button):
+        """
+        Called when the type of interval is changed.
+        """
         if self._ignore_events:
             return
         self.set_string('first_interval_type', button.get_data('idir'))
-        self.g_first_interval_up.set_sensitive(button.get_data('idir') in ['harmonic', 'up', 'up/down'])
-        self.g_first_interval_down.set_sensitive(button.get_data('idir') in ['up/down', 'down'])
+        self.g_first_interval_down.set_sensitive(button.get_data('idir') == 'melodic')
     def update_last(self, button):
+        """
+        Called when the type of interval has changed.
+        """
         if self._ignore_events:
             return
         self.set_string('last_interval_type', button.get_data('idir'))
-        self.g_last_interval_up.set_sensitive(button.get_data('idir') in ['harmonic', 'up', 'up/down'])
-        self.g_last_interval_down.set_sensitive(button.get_data('idir') in ['up/down', 'down'])
+        self.g_last_interval_down.set_sensitive(button.get_data('idir') == 'melodic')
     def guess_answer(self, g):
         if self.m_t.q_status == const.QSTATUS_NO:
             return
@@ -316,20 +303,45 @@ class Gui(abstract.Gui):
         elif q == Teacher.ERR_PICKY:
             self.g_flashbar.flash(_("You have to solve this question first."))
         else:
-            assert q == Teacher.ERRp_CONFIGURE
+            assert q == Teacher.ERR_CONFIGURE
             self.g_flashbar.flash(_("You have to configure the exercise properly"))
     def on_start_practise(self):
+        #
+        # This for loop is for backward compatability. These four
+        # variables are obsoleted!
         for n in ('first_interval_up', 'first_interval_down',
                   'last_interval_up', 'last_interval_down'):
             if n in self.m_t.m_P.header:
                 self.set_list(n, self.m_t.m_P.header[n])
+        if 'first_interval' in self.m_t.m_P.header:
+            self.set_list('first_interval_down',
+                [-n for n in self.m_t.m_P.header.first_interval if n < 0])
+            self.set_list('first_interval_up',
+                [n for n in self.m_t.m_P.header.first_interval if n > 0])
+        if 'last_interval' in self.m_t.m_P.header:
+            self.set_list('last_interval_down',
+                [-n for n in self.m_t.m_P.header.last_interval if n < 0])
+            self.set_list('last_interval_up',
+                [n for n in self.m_t.m_P.header.last_interval if n > 0])
+        self.m_t.m_custom_mode = \
+            'first_interval' not in self.m_t.m_P.header and \
+            'last_interval' not in self.m_t.m_P.header
         for n in ('first_interval_type', 'last_interval_type'):
-            if n in self.m_t.m_P.header:
+            if n in self.m_t.m_P.header and \
+                    self.m_t.m_P.header[n] in ('melodic', 'harmonic'):
                 self.set_string(n, self.m_t.m_P.header[n])
+            else:
+                self.set_string(n, 'harmonic')
+        self.g_flashbar.require_size([
+            _("The answer is: %s") % _("Last interval is largest"),
+            _("The answer is: %s") % _("First interval is largest"),
+            _("You have to solve this question first."),
+            _("You have to configure the exercise properly"),
+        ])
         gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New' to begin.")))
         self.g_new.grab_focus()
-        if self.get_bool('gui/expert_mode'):
+        if self.m_t.m_custom_mode:
             self.g_intervalconfig_box.show()
         else:
             self.g_intervalconfig_box.hide()
