@@ -276,7 +276,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
           ('MiscMenu', None, _('_Misc exercises')),
           ('TheoryMenu', None, _('_Theory')),
           ('TheoryIntervals', None, _('_Intervals'), None, None,
-            lambda o: self.m_app.handle_href('theory-intervals.html')),
+            lambda o: self.m_app.handle_href('music-theory.html')),
           ('EditMenu', None, _("_Edit")),
           ('TreeEditor', None, _('Learning tree'), None, None,
             self.do_tree_editor),
