@@ -83,7 +83,7 @@ class MultipleIntervalConfigWidget(gtk.VBox, cfg.ConfigUtils):
         box = gu.bHBox(self, expand=False)
         box.set_spacing(gnome.ui.PAD_SMALL)
         box.pack_start(gtk.Label(
-                _("Togglebuttons is for interval number:")), False)
+                _("Togglebuttons are for interval number:")), False)
         self.m_int_sel_adjustment \
              = gtk.Adjustment(1, 1, self.get_int('number_of_intervals'), 1)
         self.g_int_sel_spin = gu.nSpinButton(self.m_exname,
